@@ -223,7 +223,7 @@ class build_ext(_build_ext):
 
     def setup_shlib_compiler(self) -> None:
         compiler = self.shlib_compiler = new_compiler(
-            compiler=self.compiler, dry_run=self.dry_run, force=self.force
+            compiler=self.compiler, force=self.force
         )
         _customize_compiler_for_shlib(compiler)
 
@@ -351,54 +351,52 @@ class build_ext(_build_ext):
         log.info("writing stub loader for %s to %s", ext._full_name, stub_file)
         if compile and os.path.exists(stub_file):
             raise BaseError(stub_file + " already exists! Please delete.")
-        if not self.dry_run:
-            with open(stub_file, 'w', encoding="utf-8") as f:
-                content = (
-                    textwrap
-                    .dedent(f"""
-                    def __bootstrap__():
-                       global __bootstrap__, __file__, __loader__
-                       import sys, os, importlib.resources as irs, importlib.util
-                    #rtld   import dl
-                       with irs.files(__name__).joinpath(
-                         {os.path.basename(ext._file_name)!r}) as __file__:
-                          del __bootstrap__
-                          if '__loader__' in globals():
-                              del __loader__
-                    #rtld      old_flags = sys.getdlopenflags()
-                          old_dir = os.getcwd()
-                          try:
-                            os.chdir(os.path.dirname(__file__))
-                    #rtld        sys.setdlopenflags(dl.RTLD_NOW)
-                            spec = importlib.util.spec_from_file_location(
-                                       __name__, __file__)
-                            mod = importlib.util.module_from_spec(spec)
-                            spec.loader.exec_module(mod)
-                          finally:
-                    #rtld        sys.setdlopenflags(old_flags)
-                            os.chdir(old_dir)
-                    __bootstrap__()
-                    """)
-                    .lstrip()
-                    .replace('#rtld', '#rtld' * (not have_rtld))
-                )
-                f.write(content)
+        with open(stub_file, 'w', encoding="utf-8") as f:
+            content = (
+                textwrap
+                .dedent(f"""
+                def __bootstrap__():
+                   global __bootstrap__, __file__, __loader__
+                   import sys, os, importlib.resources as irs, importlib.util
+                #rtld   import dl
+                   with irs.files(__name__).joinpath(
+                     {os.path.basename(ext._file_name)!r}) as __file__:
+                      del __bootstrap__
+                      if '__loader__' in globals():
+                          del __loader__
+                #rtld      old_flags = sys.getdlopenflags()
+                      old_dir = os.getcwd()
+                      try:
+                        os.chdir(os.path.dirname(__file__))
+                #rtld        sys.setdlopenflags(dl.RTLD_NOW)
+                        spec = importlib.util.spec_from_file_location(
+                                   __name__, __file__)
+                        mod = importlib.util.module_from_spec(spec)
+                        spec.loader.exec_module(mod)
+                      finally:
+                #rtld        sys.setdlopenflags(old_flags)
+                        os.chdir(old_dir)
+                __bootstrap__()
+                """)
+                .lstrip()
+                .replace('#rtld', '#rtld' * (not have_rtld))
+            )
+            f.write(content)
         if compile:
             self._compile_and_remove_stub(stub_file)
 
     def _compile_and_remove_stub(self, stub_file: str):
         from distutils.util import byte_compile
 
-        byte_compile([stub_file], optimize=0, force=True, dry_run=self.dry_run)
+        byte_compile([stub_file], optimize=0, force=True)
         optimize = self.get_finalized_command('install_lib').optimize
         if optimize > 0:
             byte_compile(
                 [stub_file],
                 optimize=optimize,
                 force=True,
-                dry_run=self.dry_run,
             )
-        if os.path.exists(stub_file) and not self.dry_run:
+        if os.path.exists(stub_file):
             os.unlink(stub_file)
 
     def get_libraries(self, ext):
